import { BasicColumn, FormSchema } from '/@/components/Table';
import { h } from 'vue';
import { Switch } from 'ant-design-vue';
import { setBasStatus } from '/@/api/tigerapi/system';
import { useMessage } from '/@/hooks/web/useMessage';
import { Api } from '/@/api/sys/language';
import { useUserStore } from '/@/store/modules/user';
//列表显示
export const columns: BasicColumn[] = [
  {
    title: '物料代码',
    dataIndex: 'ITEM_CODE',
  },
  {
    title: '物料名称',
    dataIndex: 'ITEM_NAME',
  },
  {
    title: '物料类型',
    dataIndex: 'ITEM_TYPE',
  },
  {
    title: '储位规格',
    dataIndex: 'SPEC_WH',
    width: 180,
  },
  {
    title: '规格',
    dataIndex: 'SPEC',
  },
  {
    title: '单位',
    dataIndex: 'UNIT',
  },
  {
    title: '产品有效期',
    dataIndex: 'VALIDITY_DAYS',
  },
  {
    title: '预存天数',
    dataIndex: 'DepositDays',
  },
  {
    title: '延期天数',
    dataIndex: 'PostponeDays',
  },

  {
    title: '是否启用',
    dataIndex: 'IS_ACTIVE',
    width: 120,
    customRender: ({ record }) => {
      if (!Reflect.has(record, 'pendingStatus1')) {
        record.pendingStatus1 = false;
      }
      const id = 'd70918d6fe474b96b6dabba5c8679c30';
      const roles = useUserStore().getUserInfo.roles;
      const is_active = roles.some((item) => item.MENU_CODE === id);
      return h(Switch, {
        checked: record.IS_ACTIVE === 'Y',
        checkedChildren: '已启用',
        unCheckedChildren: '已禁用',

        disabled: !is_active,
        loading: record.pendingStatus1,
        onChange(checked: boolean) {
          const oldStatus = record.IS_ACTIVE;
          record.pendingStatus1 = true;
          const newStatus = checked ? 'Y' : 'N';
          console.log(10, newStatus);
          const { createMessage } = useMessage();
          record.IS_ACTIVE = newStatus;
          setBasStatus(record)
            .then(() => {
              createMessage.success(`是否启用已成功修改`);
            })
            .catch(() => {
              createMessage.error('修改失败');
              record.IS_ACTIVE = oldStatus;
            })
            .finally(() => {
              record.pendingStatus1 = false;
            });
        },
      });
    },
  },
  {
    title: '是否超期收料',
    dataIndex: 'IsAllowOverdue',
    width: 120,
    customRender: ({ record }) => {
      if (!Reflect.has(record, 'pendingStatus1')) {
        record.pendingStatus1 = false;
      }
      const id = 'c3f57fcd469b43f48d37dabbb495c728';
      const roles = useUserStore().getUserInfo.roles;
      const is_active = roles.some((item) => item.MENU_CODE === id);
      return h(Switch, {
        checked: record.IsAllowOverdue === 'Y',
        checkedChildren: '已启用',
        unCheckedChildren: '已禁用',
        disabled: !is_active,
        loading: record.pendingStatus1,
        onChange(checked: boolean) {
          const oldStatus = record.IsAllowOverdue;
          record.pendingStatus1 = true;
          const newStatus = checked ? 'Y' : 'N';
          console.log(10, newStatus);
          const { createMessage } = useMessage();
          record.IsAllowOverdue = newStatus;
          setBasStatus(record)
            .then(() => {
              createMessage.success(`是否启用已成功修改`);
            })
            .catch(() => {
              createMessage.error('修改失败');
              record.IsAllowOverdue = oldStatus;
            })
            .finally(() => {
              record.pendingStatus1 = false;
            });
        },
      });
    },
  },
  {
    title: '是否先进先出',
    dataIndex: 'ENABLE_FIFO',
    customRender: ({ record }) => {
      if (!Reflect.has(record, 'pendingStatus2')) {
        record.pendingStatus2 = false;
      }
      const id = '22ddd0c8449e4bf5bfc171d2a9d62132';
      const roles = useUserStore().getUserInfo.roles;
      const is_active = roles.some((item) => item.MENU_CODE === id);
      return h(Switch, {
        checked: record.ENABLE_FIFO === 'Y',
        checkedChildren: '是',
        unCheckedChildren: '否',
        disabled: !is_active,
        loading: record.pendingStatus2,
        onChange(checked: boolean) {
          const oldStatus = record.ENABLE_FIFO;
          record.pendingStatus2 = true;
          const newStatus = checked ? 'Y' : 'N';
          console.log(10, newStatus);
          const { createMessage } = useMessage();
          record.ENABLE_FIFO = newStatus;
          setBasStatus(record)
            .then(() => {
              createMessage.success(`是否先进先出已成功修改`);
            })
            .catch(() => {
              createMessage.error('修改失败');
              record.ENABLE_FIFO = oldStatus;
            })
            .finally(() => {
              record.pendingStatus2 = false;
            });
        },
      });
    },
  },
  {
    title: '是否超发',
    dataIndex: 'DLVY_TYPE',
    customRender: ({ record }) => {
      if (!Reflect.has(record, 'pendingStatus3')) {
        record.pendingStatus3 = false;
      }
      const id = '16b798a59e4c41979e6b961bb7cdff98';
      const roles = useUserStore().getUserInfo.roles;
      const is_active = roles.some((item) => item.MENU_CODE === id);
      return h(Switch, {
        checked: record.DLVY_TYPE === 1,
        checkedChildren: '可超发',
        unCheckedChildren: '不超发',

        disabled: !is_active,
        loading: record.pendingStatus3,
        onChange(checked: boolean) {
          const oldStatus = record.DLVY_TYPE;
          record.pendingStatus3 = true;
          const newStatus = checked ? 1 : 0;
          console.log(10, newStatus);
          const { createMessage } = useMessage();
          record.DLVY_TYPE = newStatus;
          setBasStatus(record)
            .then(() => {
              createMessage.success(`是否超发已成功修改`);
            })
            .catch(() => {
              createMessage.error('修改失败');
              record.DLVY_TYPE = oldStatus;
            })
            .finally(() => {
              record.pendingStatus3 = false;
            });
        },
      });
    },
  },
  {
    title: '备注',
    dataIndex: 'REMARK',
  },

  {
    title: '更新时间',
    dataIndex: 'UPDATE_TIME',
  },
  {
    title: '更新人',
    dataIndex: 'UPDATE_USER',
  },
];

//模糊查询
export const searchFormSchema: FormSchema[] = [
  {
    field: 'ITEM_CODE',
    label: '物料编码',
    component: 'Input',
    colProps: { span: 8 },
  },
];
//新增组件export const
export const formSchema: FormSchema[] = [
  {
    field: 'ITEM_CODE',
    label: '物料代码',
    required: true,
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'ID',
    label: 'ID',
    component: 'Input',
    show: false,
  },
  {
    field: 'FACTORY',
    label: '工厂代码',
    component: 'Input',
    show: false,
    colProps: { span: 8 },
  },
  {
    field: 'ITEM_NAME',
    label: '物料名称',
    required: true,
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'ITEM_TYPE',
    label: '物料类型',
    required: true,
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'ITEM_VER',
    label: '物料版本',
    //required: true,
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'SPEC',
    label: '规格',
    required: true,
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'SPEC_WH',
    label: '储位规格',
    //required: true,
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'ITEM_LINE',
    label: '产品机种',
    //required: true,
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'ITEM_MODEL',
    label: '产品机型',
    //required: true,
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'UNIT',
    label: '单位',
    required: true,
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'VALIDITY_DAYS',
    label: '产品有效期',
    required: true,
    component: 'InputNumber',
    colProps: { span: 8 },
  },
  {
    field: 'DepositDays',
    label: '预存天数',
    component: 'InputNumber',
    colProps: { span: 8 },
  },
  {
    field: 'IS_ACTIVE',
    label: '是否启用',
    show: false,
    component: 'InputNumber',
    colProps: { span: 8 },
  },
  {
    field: 'ENABLE_FIFO',
    label: '是否先进先出',
    show: false,
    component: 'InputNumber',
    colProps: { span: 8 },
  },
  {
    field: 'DLVY_TYPE',
    label: '是否超发',
    show: false,
    component: 'InputNumber',
    colProps: { span: 8 },
  },
  {
    field: 'REMARK',
    label: '备注',
    // required: true,
    component: 'Input',
    colProps: { span: 24 },
  },
];
//批量更新明细
export const columns_UPD: BasicColumn[] = [
  {
    title: '序号',
    resizable: true,
    sorter: true,
    editRow: true,
    editable: true,
    dataIndex: 'BILLLINE',
    width: 100,
    ifShow: false,
  },
  {
    title: '物料编码',
    resizable: true,
    sorter: true,
    dataIndex: 'ITEM_CODE',
    width: 200,
  },
  {
    title: '物料名称',
    resizable: true,
    sorter: true,
    dataIndex: 'ITEM_NAME',
    width: 200,
  },
  {
    title: '产品有效期',
    resizable: true,
    sorter: true,
    dataIndex: 'VALIDITY_DAYS',
    width: 200,
  },
  {
    title: '预存天数',
    resizable: true,
    sorter: true,
    dataIndex: 'DepositDays',
    width: 200,
  },
];
//批量更新弹框
export const ItemColumns: FormSchema[] = [
  {
    field: 'VALIDITY_DAYS',
    label: '产品有效期',
    required: true,
    component: 'Input',
    colProps: { span: 12 },
    componentProps: {
      placeholder: '请输入',
    },
    rules: [
      { required: true },
      {
        pattern: /(^[1-9]\d*$)|(^[1-9]\d*[.]{1}[0-9]{1,2}$)|(^0[.]{1}[0-9]{1,2}$)/,
        message: '只能输入正整数，且最多两位小数点',
      },
    ],
  },
  {
    field: 'DepositDays',
    label: '预存天数',
    required: true,
    component: 'Input',
    colProps: { span: 12 },
    componentProps: {
      placeholder: '请输入',
    },
    rules: [
      { required: true },
      {
        pattern: /(^[1-9]\d*$)|(^[1-9]\d*[.]{1}[0-9]{1,2}$)|(^0[.]{1}[0-9]{1,2}$)/,
        message: '只能输入正整数，且最多两位小数点',
      },
    ],
  },
  {
    field: 'ITEM_CODE',
    label: '物料编码',
    component: 'Input',
    colProps: { span: 0 },
    show: false,
  },
];
